
{% load i18n %}

<p class="text-muted">
    {% translate 'The sovereignty timer list is automatically updated every 30 seconds. Progress for any active campaigns will be shown as <i>Previous - Trend - Current</i>.' %}
</p>

<div class="panel panel-default">
    <div class="panel-heading">
        <div class="panel-title">{% translate "Sovereignty Campaign List" %}</div>
    </div>

    <div class="panel-body">
        <table class="table table-striped aa-sovtimer-campaigns" style="width: 100%; border-collapse: collapse !important;">
            <thead>
                <th class="aa-sovtimer-campaigns-type-column">{% translate 'Type' %}</th>
                <th class="aa-sovtimer-campaigns-system-column">{% translate 'System' %}</th>
                <th class="aa-sovtimer-campaigns-constellation-column">{% translate 'Constellation' %}</th>
                <th class="aa-sovtimer-campaigns-region-column">{% translate 'Region' %}</th>
                <th class="aa-sovtimer-campaigns-defender-column">{% translate 'Owner / Defender' %}</th>
                <th class="aa-sovtimer-campaigns-adm-column">
                    {% translate 'ADM' %}
                    <sup>
                        <abbr title="{% translate 'This is not the systems overall ADM. This is the defense multiplier towards the structure itself.' %}">
                            <i class="fas fa-question-circle fa-fw"></i>
                        </abbr>
                    </sup>
                </th>
                <th class="aa-sovtimer-campaigns-start-datetime-column">{% translate 'Start' %}</th>
                <th class="aa-sovtimer-campaigns-remaining-time-column">{% translate 'Remaining' %}</th>
                <th class="aa-sovtimer-campaigns-progress-column">{% translate 'Progress' %}</th>
            </thead>

            <tbody></tbody>
        </table>
    </div>
</div>
